# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ProductRetrieveDetailsParams"]


class ProductRetrieveDetailsParams(TypedDict, total=False):
    product_id: Required[Annotated[str, PropertyInfo(alias="productId")]]
    """Product ID"""
